########
check_po
########

Test if the po is fully translated without fuzzy.

.. image:: https://secure.travis-ci.org/novapost/check_po.png?branch=master
   :alt: Build Status
   :target: https://secure.travis-ci.org/novapost/check_po
.. image:: https://coveralls.io/repos/novapost/check_po/badge.png?branch=master
   :alt: Coverage Status on master
   :target: https://coveralls.io/r/novapost/check_po?branch=master
.. image:: https://pypip.in/v/check_po/badge.png
   :target: https://crate.io/packages/check_po/
.. image:: https://pypip.in/d/check_po/badge.png
   :target: https://crate.io/packages/check_po/

`Documentation<https://github.com/novafloss/check_po/wiki>`_
